Class: Deja::Judges::Anthropic
- Inherits:
-
Base
- Object
- Base
- Deja::Judges::Anthropic
show all
- Defined in:
- lib/deja/judges/anthropic.rb
Overview
Judge backed by the Anthropic Ruby SDK. Use ‘::Anthropic` for the SDK constant — bare `Anthropic` would resolve to this class.
Constant Summary
collapse
- DEFAULTS =
{
model: "claude-sonnet-4-5",
max_tokens: 512,
system: "You evaluate whether a candidate value meets a set of requirements. " \
"Use the structured output schema to return your verdict.",
}.freeze
Instance Attribute Summary
Attributes inherited from Base
#client
Class Method Summary
collapse
Instance Method Summary
collapse
Methods inherited from Base
#initialize
Class Method Details
.client_description ⇒ Object
21
22
23
|
# File 'lib/deja/judges/anthropic.rb', line 21
def self.client_description
"Anthropic::Client"
end
|
.handles?(client) ⇒ Boolean
17
18
19
|
# File 'lib/deja/judges/anthropic.rb', line 17
def self.handles?(client)
defined?(::Anthropic::Client) && client.is_a?(::Anthropic::Client)
end
|
Instance Method Details
#defaults ⇒ Object
25
26
27
|
# File 'lib/deja/judges/anthropic.rb', line 25
def defaults
DEFAULTS
end
|